# Release Notes
This document contains high level documented changes to the pyhpeuxi package.

## Version 1.0.0 (10/02/2025) 
1. Inital Release

## Version 1.0.1 (12/02/2025) 
1. Moved Pagination into the common.py script 

## Version 1.0.2 (12/03/2025) 
1. Added in function to obtain token object from file.
2. Added in function to obtain api credentials object from file.
3. Added copywrite licence details to py module files.
4. Added in export to CSV function into Utils_UXI module

